@@ -1,13 +1,15 @@
-from PySide2.QtWidgets import *
-from PySide2.QtGui import *
-from PySide2.QtCore import *
 from CIDAN.GUI.Data_Interaction.Signals import *
+
+
 class Thread(QThread):
     def __init__(self, data_handler, parent=None):
         QThread.__init__(self, parent)
         self.exiting = False
-        self.signal = MatrixSignal()
+        self.signal = BoolSignal()
         self.data_handler = data_handler
 
     def run(self):
-        pass
\ No newline at end of file
+        pass
+
+    def endThread(self, success):
+        pass
