@@ -1,5 +1,5 @@
 import os
-from typing import Tuple
+from typing import Tuple, List
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -14,12 +14,13 @@ from scipy import ndimage
 def load_filter_tif_stack(*, path, filter: bool, median_filter: bool,
                           median_filter_size: Tuple[int, int, int],
                           z_score: bool, slice_stack: bool,
-                          slice_every, slice_start: int):
+                          slice_every, slice_start: int, crop_stack: bool,
+                          crop_x: List[int], crop_y: List[int]):
     """
     This function reads a tiff stack file
     Parameters
     ----------
-    path The path to a single tif stack or a list of paths to many tiff stacks
+    path The path to a single tif stack or to a directory of tiff stacks
 
 
     Returns
@@ -27,36 +28,44 @@ def load_filter_tif_stack(*, path, filter: bool, median_filter: bool,
     a 3D numpy array with the tiff files together
 
     """
+    print(path)
 
-    if type(path) == list or os.path.isdir(path):
+    if os.path.isdir(path):
         volumes = []
         paths = path if type(path) == list else sorted(os.listdir(path))
-
+        print(paths)
         for num, x in enumerate(paths):
             file_path = x if type(path) == list else os.path.join(path, x)
             image = tifffile.imread(file_path)
+            if len(image.shape) == 2:
+                image = image.reshape((1,image.shape[0],image.shape[1]))
             if slice_stack:
-                image = image[slice_start::slice_every, :, :]
+                image = image[slice_start::slice_every]
+            if crop_stack:
+                image = image[:, crop_x[0]:crop_x[1], crop_y[0]:crop_y[1]]
             if filter:
                 image = filter_stack(stack=image, median_filter=median_filter,
                                      median_filter_size=median_filter_size,
                                      z_score=z_score)
             volumes.append(image)
-            print("Loading: " + x)
+            # print("Loading: " + x)
 
         image = np.vstack(volumes)
         del volumes
-        return image
+        return image.astype(np.float64)
     if os.path.isfile(path):
         # return ScanImageTiffReader(path).data()
         image = tifffile.imread(path)
-
+        if len(image.shape) == 2:
+            image = image.reshape((1, image.shape[0], image.shape[1]))
         if slice_stack:
-            image = image[slice_start::slice_every, :, :]
+            image = image[slice_start::slice_every]
+        if crop_stack:
+            image = image[:, crop_x[0]:crop_x[1], crop_y[0]:crop_y[1]]
         if filter:
             image = filter_stack(stack=image, median_filter=median_filter,
                                  median_filter_size=median_filter_size, z_score=z_score)
-        return image
+        return image.astype(np.float64)
     raise Exception("Invalid Inputs folders not allowed currently ")
     # vol=ScanImageTiffReader(file_path).data()
 
@@ -109,16 +118,18 @@ def save_image(volume: np.ndarray, name: str, directory: str, shape: tuple,
 
 def filter_stack(*, stack: np.ndarray, median_filter: bool,
                  median_filter_size: Tuple[int, int, int],
-                 z_score: bool, ):
+                 z_score: bool):
+    if median_filter:
+        # stack = ndimage.median_filter(stack, median_filter_size)
+        stack = ndimage.filters.convolve(stack, np.full((3, 3, 3), 1.0 / 27))
     if z_score:
         stack_t = np.transpose(stack, (1, 2, 0))
-        shape = (1, stack_t.shape[1], stack_t.shape[2])
-        std = np.std(stack_t, axis=0).reshape(shape)
-        mean = np.mean(stack_t, axis=0).reshape(shape)
+        shape = (stack.shape[1], stack.shape[2], 1)
+        std = np.std(stack_t, axis=2).reshape(shape)
+        mean = np.mean(stack_t, axis=2).reshape(shape)
         stack_t = (stack_t - mean) / std
         stack = np.transpose(stack_t, (2, 0, 1))
-    if median_filter:
-        stack = ndimage.median_filter(stack, median_filter_size)
+
     return stack
 
 
